<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Digital
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function digital_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function digital_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function digital_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function digital_merge_value( &$css, $values ) {
	foreach ( (array) $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function digital_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = digital()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Digital_Sanitize::background( digital_get_settings( 'mts_background' ) );

	// Top bar Background.
	$css['global']['.top-bar'] = Digital_Sanitize::background( digital_get_settings( 'top_bar_background' ) );

	// Header Background.
	$css['global']['.main-header #header'] = Digital_Sanitize::background( digital_get_settings( 'header_background' ) );
	// Home Header Background.
	$css['global']['.main-header.home-header #header, .main-header.home-header #header.sticky-navigation.sticky-navigation-active'] = Digital_Sanitize::background( digital_get_settings( 'home_header_background' ) );

	// Content Font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'content_font' ) ) );
	// Single Post Content Font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_post_content_font' ) ) );
	// Homepage Logo Font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'digital_home_logo' ) ) );
	// Homepage Primary Navigation font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'home_primary_navigation_font' ) ) );
	// Logo Font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'digital_logo' ) ) );
	// Primary Navigation font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'primary_navigation_font' ) ) );
	// Homepage post title font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'home_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'archive_page_title_font' ) ) );
	// Header Featured font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'header_featured_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'header_featured_text_font' ) ) );
	// Pagination.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pagination_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'loadmore_font' ) ) );
	// Breadcrumbs font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'breadcrumb_font' ) ) );
	// Single post title font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_title_font' ) ) );
	// Single Page titles font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_page_titles_font' ) ) );
	// Related Posts Section title font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'related_posts_text_font' ) ) );
	// Single subscribe box.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_subscribe_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_subscribe_text_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_subscribe_input_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_subscribe_submit_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'authorbox_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'authorbox_author_name_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'authorbox_text_font' ) ) );
	// Footer Nav.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'footer_nav_font' ) ) );
	// Sidebar widget title font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'sidebar_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'sidebar_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'sidebar_links_widgets' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'sidebar_post_title' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'sidebar_big_post_title' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'sidebar_postinfo_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'sidebar_subscribe_title_font' ) ) );
	// Footer widget title font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'top_footer_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'top_footer_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'footer_links_widgets' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'top_footer_post_title' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'footer_big_post_title' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'top_footer_meta_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'footer_subscribe_title_font' ) ) );
	// Copyrights section font.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'copyrights_font' ) ) );
	// H1 title in the content.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Digital_Sanitize::background( digital_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Digital_Sanitize::background( digital_get_settings( 'mts_copyrights_background' ) );

	digital_dynamic_css_skin( $css );
	digital_sidebar_position( $css );
	digital_header( $css );
	digital_sidebar_styling( $css );
	digital_homepage( $css );
	digital_pages_title( $css );
	digital_post_layouts( $css );
	digital_post_pagination( $css );
	digital_footer( $css );
	digital_pricing( $css );
	digital_archives( $css );
	digital_copyrights( $css );
	digital_single( $css );
	digital_single_social_buttons( $css );
	digital_misc_css( $css );

	return apply_filters( 'digital_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme   = Digital_Sanitize::color( digital_get_settings( 'primary_color_scheme' ) );
	$secondary_color_scheme = Digital_Sanitize::color( digital_get_settings( 'secondary_color_scheme' ) );

	// Text Color.
	$elements = array(
		'a',
		'.reply a',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'.fn a',
		'.widget .sbutton',
		'.layout-subscribe .widget #wp-subscribe .title span',
		'blockquote:after',
		'article ul li::before',
		'.single .pagination a .current:hover',
		'blockquote::before',
		'.postauthor h5 a:hover',
		'.button.border',
		'.main-header:not(.home-header) .menu-item-has-children>a:after',
		'#site-footer a:hover',
		'#site-footer .widget.widget_archive a:hover',
		'#site-footer .widget.widget_categories a:hover',
		'#site-footer .widget.widget_pages a:hover',
		'#site-footer .widget.widget_meta a:hover',
		'#site-footer .widget.widget_nav_menu a:hover',
		'.page-template-pricing .pricing-text p:before',
		'.page-template-pricing .pricing-text li:before',
		'.page-template-pricing .pricing-text div:before',
		'.page-template-pricing .pricing-text span:before',
		'#primary-navigation .navigation ul ul a:hover',
		'.home-header #primary-navigation li:hover > a',
		'#primary-navigation li:hover > a',
		'#primary-navigation li.current-menu-item > a',
	);

	$css['global'][ digital_implode( $elements ) ]['color'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.layout-1 .latestPost a:hover',
		'.review-total-only.small-thumb .review-result-wrapper i',
		'.latestPost .post-info a:hover',
		'.post-info a:hover',
		'.tagcloud a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
		'.readMore a:hover',
	);
	$css['global'][ digital_implode( $elements ) ]['color'] = $secondary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.button',
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.pagination a:hover',
		'.single .pagination a:hover .current',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'.widget_product_search button[type="submit"]',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'.widget .wp-subscribe-wrap h4.title span.decor:after',
		'.woocommerce .bypostauthor:after',
		'#wpmm-megamenu .review-total-only',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce a.button:hover',
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce button.button.alt:hover',
		'.woocommerce a.button.alt:hover',
		'.latestPost-review-wrapper',
		'.latestPost .review-type-circle.latestPost-review-wrapper',
		'.woocommerce span.onsale',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'#sidebar .widget h3::before',
		'.button:hover',
		'.button.border:hover',
		'#primary-navigation li:hover::before',
		'.testimonials-section .owl-controls .owl-dot.active span',
		'.testimonials-section .owl-controls .owl-dot:hover span',
		'.breadcrumb .separator',
		'.post-info > span::after',
		'.owl-controls .owl-dot.active span',
		'.owl-controls .owl-dot:hover span',
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.single-testimonial-heading:after',
		'.video-list .caption',
	);

	$css['global'][ digital_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	// Border Color.
	$elements = array(
		'.button.border',
		'.widget #s:focus',
	);

	$css['global'][ digital_implode( $elements ) ]['border-color'] = $primary_color_scheme;

	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper']['background-color'] = $primary_color_scheme;

	// Secondary Color.
	$elements = array(
		'body a:hover',
		'.shareit-circular.standard .fa:hover',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.layout-default .latestPost .title a:hover',
		'#sidebar .widget li a:hover',
		'.title a:hover',
		'#tabber .inside li a:hover',
		'.related-posts .title a:hover',
		'.error404 .sbutton',
		'.search .sbutton',
		'.widget #wp-subscribe input.submit',
		'.category-posts li.no-thumb.horizontal-small:after',
		'.advanced-recent-posts li.no-thumb.horizontal-small:after',
		'.popular-posts li.no-thumb.horizontal-small:after',
		'.related-posts-widget li.no-thumb.horizontal-small:after',
		'.author-posts-widget li.no-thumb.horizontal-small:after',
		'.widget .wpt_widget_content .tab_title.selected a',
		'.widget .wp_review_tab_widget_content .tab_title.selected a',
		'#copyright-note a',
		'#primary-navigation .navigation .sub-menu ul ul a:hover',
		'.home-header #primary-navigation .sub-menu li:hover > a',
		'#primary-navigation .sub-menu li:hover > a',
		'#primary-navigation .sub-menu li.current-menu-item > a',
		'#sidebar .widget a:hover',
		'.aboutme-social a:hover',
	);
	$css['global'][ digital_implode( $elements ) ]['color'] = $secondary_color_scheme;

	// Secondary Background Color.
	$elements = array(
		'.instagram-button a',
		'.widget .wp_review_tab_widget_content ul.wp-review-tabs li:hover::before',
		'.widget .wpt_widget_content ul.wpt-tabs li:hover::before',
		'.widget .wp_review_tab_widget_content .tab_title.selected a::before',
		'.widget .wpt_widget_content .tab_title.selected a::before',
		'.widget_product_search button[type="submit"]',
		'.tags a:hover',
		'.widget.wp_subscribe',
		'#sidebar .widget.wp_subscribe',
		'#commentform input#submit:hover',
		'#mtscontact_submit:hover',
		'.tagcloud a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'#searchsubmit',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
		'.woocommerce #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'.home-header #header.sticky-navigation-active',
	);
	$css['global'][ digital_implode( $elements ) ]['background-color'] = $secondary_color_scheme;

	// Secondary Border Color.
	$elements = array(
		'.page-numbers.current',
		'.pagination a:hover',
		'.tags a:hover',
		'.tagcloud a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page #content nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
		'.woocommerce #content nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page #content nav.woocommerce-pagination ul li a:focus',
	);

	$css['global'][ digital_implode( $elements ) ]['border-color'] = $secondary_color_scheme;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = digital_get_settings( 'mts_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( digital_get_settings( 'mts_floating_social_buttons' ) ) {

			$shareit_class = array(
				'.right .social-share-floating-buttons .shareit.shareit-default',
				'.right .social-share-floating-buttons .shareit.standard',
				'.right .social-share-floating-buttons .shareit.shareit-circular',
			);

			$css['global'][ digital_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ digital_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ digital_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ digital_implode( $shareit_class ) ]['margin-right'] = '50px';
		}
	}
	if ( 'mts_nosidebar' == mts_custom_sidebar() ) {
		$css['global']['.single_post header']['width'] = '100%';
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_header( &$css ) {

	// Header.
	$header_class = array(
		'#header',
	);
	digital_merge_value( $css['global'][ digital_implode( $header_class ) ], Digital_Sanitize::margin( digital_get_settings( 'header_margin' ) ) );
	digital_merge_value( $css['global'][ digital_implode( $header_class ) ], Digital_Sanitize::padding( digital_get_settings( 'header_padding' ) ) );
	// Header Border.
	$header_border = Digital_Sanitize::border( digital_get_settings( 'header_border' ) );
	$css['global'][ digital_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Primary Nav.
	$css['global']['#primary-navigation .navigation ul ul a']['color']       = Digital_Sanitize::color( digital_get_settings( 'main_navigation_dropdown_color' ) );
	$css['global']['#primary-navigation .navigation ul ul a:hover']['color'] = Digital_Sanitize::color( digital_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Homepage Header Position.
	$slider  = digital_get_settings( 'home_slider' );
	$options = digital_get_settings( 'homepage_layout' );

	if ( is_page_template( 'page-home.php' ) && ! empty( $slider ) && is_array( $slider ) && ( 'Hero Section' == $options['enabled']['hero'] ) ) {
		$css['global']['.home-header #header']['position'] = 'absolute';
	}
	// Pages Header Button
	$nav_button_class       = array(
		'#site-header .nav-button .button',
	);
	$nav_button_hover_class = array(
		'#site-header .nav-button .button:hover',
	);
	// Nav Button Background & color.
	$css['global'][ digital_implode( $nav_button_class ) ]['background-color'] = Digital_Sanitize::color( digital_get_settings( 'nav_button_bg' ) );
	$css['global'][ digital_implode( $nav_button_class ) ]['border-color']     = Digital_Sanitize::color( digital_get_settings( 'nav_button_bg' ) );
	$css['global'][ digital_implode( $nav_button_class ) ]['color']            = Digital_Sanitize::color( digital_get_settings( 'nav_button_color' ) );
	$css['global'][ digital_implode( $nav_button_hover_class ) ]['color']      = Digital_Sanitize::color( digital_get_settings( 'nav_button_bg' ) );
	// Home Header button
	$nav_button_class       = array(
		'#site-header.home-header .nav-button .button',
	);
	$nav_button_hover_class = array(
		'#site-header.home-header .nav-button .button:hover',
	);
	// Nav Button Background & color.
	$css['global'][ digital_implode( $nav_button_class ) ]['background-color'] = Digital_Sanitize::color( digital_get_settings( 'home_nav_button_bg' ) );
	$css['global'][ digital_implode( $nav_button_class ) ]['border-color']     = Digital_Sanitize::color( digital_get_settings( 'home_nav_button_bg' ) );
	$css['global'][ digital_implode( $nav_button_class ) ]['color']            = Digital_Sanitize::color( digital_get_settings( 'home_nav_button_color' ) );
	$css['global'][ digital_implode( $nav_button_hover_class ) ]['color']      = Digital_Sanitize::color( digital_get_settings( 'home_nav_button_bg' ) );
	// Header Ad.
	digital_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Digital_Sanitize::margin( digital_get_settings( 'mts_header_adcode_margin' ) ) );
	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Digital_Sanitize::color( digital_get_settings( 'navigation_ad_background' ) );

	if ( empty( digital_get_settings( 'nav_button' ) ) ) {
		$css['global']['.header-default #primary-navigation']['float'] = 'right';
		//responsive
		$css['@media screen and (max-width: 865px)']['.header-default a#pull']['padding-right'] = '15px';
		$css['@media screen and (max-width: 865px)']['.header-default a#pull:after']['right']   = '-3px';
		$css['@media screen and (max-width: 865px)']['.header-default .logo-wrap']['float']     = 'left';
		$css['@media screen and (max-width: 865px)']['.header-default .logo-wrap']['margin']    = '0px';
	}
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.single-social-share-section .shareit'] = Digital_Sanitize::background( digital_get_settings( 'social_styling_background' ) );
	digital_merge_value( $css['global']['.single-social-share-section .shareit'], Digital_Sanitize::padding( digital_get_settings( 'social_styling_padding' ) ) );
	digital_merge_value( $css['global']['.single-social-share-section .shareit'], Digital_Sanitize::margin( digital_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Digital_Sanitize::border( digital_get_settings( 'social_styling_border' ) );
	$css['global']['.single-social-share-section .shareit'][ $social_border ['direction'] ] = $social_border ['value'];

	// Floating Social share.
	$css['global']['.social-share-floating-buttons .shareit'] = Digital_Sanitize::background( digital_get_settings( 'social_floating_styling_background' ) );
	digital_merge_value( $css['global']['.social-share-floating-buttons .shareit'], Digital_Sanitize::margin( digital_get_settings( 'social_floating_styling_margin' ) ) );

	// Floating Social share border.
	$social_border = Digital_Sanitize::border( digital_get_settings( 'social_floating_styling_border' ) );
	$css['global']['.social-share-floating-buttons .shareit'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = digital_get_settings( 'social_button_layout' );
	$social_button_position = digital_get_settings( 'social_button_floating_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.social-share-floating-buttons .shareit-' . $social_button_layout;
	} else {
		$share_class = '.social-share-floating-buttons .shareit.' . $social_button_layout;
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_sidebar_styling( &$css ) {

	// Sidebar.
	digital_merge_value( $css['global']['.sidebar .widget'], Digital_Sanitize::background( digital_get_settings( 'mts_sidebar_styling_background' ) ) );
	digital_merge_value( $css['global']['.sidebar .widget'], Digital_Sanitize::margin( digital_get_settings( 'mts_sidebar_styling_margin' ) ) );
	digital_merge_value( $css['global']['.sidebar .widget'], Digital_Sanitize::padding( digital_get_settings( 'mts_sidebar_styling_padding' ) ) );

	// Sidebar border.
	$sidebar_border = Digital_Sanitize::border( digital_get_settings( 'sidebar_styling_border' ) );
	$css['global']['.sidebar .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3';
	$css['global'][ $sidebar_title ] = Digital_Sanitize::background( digital_get_settings( 'mts_sidebar_title_styling_background' ) );
	digital_merge_value( $css['global'][ $sidebar_title ], Digital_Sanitize::padding( digital_get_settings( 'mts_sidebar_title_styling_padding' ) ) );
	digital_merge_value( $css['global'][ $sidebar_title ], Digital_Sanitize::margin( digital_get_settings( 'mts_sidebar_title_styling_margin' ) ) );
	// Sidebar Title border.
	$sidebar_title_border = Digital_Sanitize::border( digital_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_homepage( &$css ) {

	/**
	 * Slider Section.
	 */
	$slider = digital_get_settings( 'home_slider' );
	$i      = 0;
	if ( ! empty( $slider ) && is_array( $slider ) ) {
		foreach ( $slider as $slide ) {
			++$i;
			$css['global'][ '.slider-item.item-' . $i ]['background-image'] = 'url(' . $slide['slider_background'] . ')';

			$css['global'][ '.slider-item.item-' . $i . ' .slider-overlay' ]['background']     = Digital_Sanitize::color( $slide['slider_overlay'] );
			$css['global'][ '.slider-item.item-' . $i . ' .slider-title' ]['color']            = Digital_Sanitize::color( $slide['slider_title_color'] );
			$css['global'][ '.slider-item.item-' . $i . ' .slider-text' ]['color']             = Digital_Sanitize::color( $slide['slider_desc_color'] );
			$css['global'][ '.slider-item.item-' . $i . ' .button' ]['color']                  = Digital_Sanitize::color( $slide['slider_button_text_color'] );
			$css['global'][ '.slider-item.item-' . $i . ' .button' ]['background-color']       = Digital_Sanitize::color( $slide['slider_button_bg_color'] );
			$css['global'][ '.slider-item.item-' . $i . ' .button:hover' ]['color']            = Digital_Sanitize::color( $slide['slider_button_text_hover_color'] );
			$css['global'][ '.slider-item.item-' . $i . ' .button:hover' ]['background-color'] = Digital_Sanitize::color( $slide['slider_button_bg_hover_color'] );
		}
	}
	$css['global']['.slider-section'] = Digital_Sanitize::background( digital_get_settings( 'slider_background' ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'slider_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'slider_text_font' ) ) );
	digital_merge_value( $css['global']['.slider-section .slider-item .container'], Digital_Sanitize::padding( digital_get_settings( 'slider_padding' ) ) );
	digital_merge_value( $css['global']['.slider-section'], Digital_Sanitize::margin( digital_get_settings( 'slider_margin' ) ) );

	// Featured On Section
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'brands_heading_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'brands_subheading_font' ) ) );
	$css['global']['.brands-section'] = Digital_Sanitize::background( digital_get_settings( 'brands_background' ) );
	digital_merge_value( $css['global']['.brands-section'], Digital_Sanitize::padding( digital_get_settings( 'brands_padding' ) ) );
	digital_merge_value( $css['global']['.brands-section'], Digital_Sanitize::margin( digital_get_settings( 'brands_margin' ) ) );
	$featured_on_svg_position = digital_get_settings( 'featured_on_svg_position', array() );
	foreach ( $featured_on_svg_position as $key => $position ) {
		$css['global']['.section-svg.featured-on-svg'][ $key ] = $position;
	}

	// Single Testimonial
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_testimonial_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_testimonial_text_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'single_testimonial_user_font' ) ) );
	$css['global']['.single-testimonial-section'] = Digital_Sanitize::background( digital_get_settings( 'single_testimonial_background' ) );
	digital_merge_value( $css['global']['.single-testimonial-section'], Digital_Sanitize::padding( digital_get_settings( 'single_testimonial_padding' ) ) );
	digital_merge_value( $css['global']['.single-testimonial-section'], Digital_Sanitize::margin( digital_get_settings( 'single_testimonial_margin' ) ) );
	$single_testimonial_svg_position = digital_get_settings( 'single_testimonial_svg_position', array() );
	foreach ( $single_testimonial_svg_position as $key => $position ) {
		$css['global']['.section-svg.single-testimonial-svg'][ $key ] = $position;
	}

	//Featured Videos
	$css['global']['.featured-videos-section'] = Digital_Sanitize::background( digital_get_settings( 'featured_video_background' ) );
	digital_merge_value( $css['global']['.featured-videos-section'], Digital_Sanitize::padding( digital_get_settings( 'featured_video_padding' ) ) );
	digital_merge_value( $css['global']['.featured-videos-section'], Digital_Sanitize::margin( digital_get_settings( 'featured_video_margin' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'featured_video_tagline_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'featured_video_title_font' ) ) );
	$css['global']['.video-list .caption']['background-color']       = Digital_Sanitize::color( digital_get_settings( 'video_play_button_bg' ) );
	$css['global']['.video-list .caption:hover']['background-color'] = Digital_Sanitize::color( digital_get_settings( 'video_play_button_hover_bg' ) );
	$videos_svg_position = digital_get_settings( 'videos_svg_position', array() );
	foreach ( $videos_svg_position as $key => $position ) {
		$css['global']['.section-svg.videos-svg'][ $key ] = $position;
	}

	/**
	 * Three Column Section.
	 */
	$threefeature = digital_get_settings( 'home_threefeature' );
	$i            = 0;
	if ( ! empty( $threefeature ) && is_array( $threefeature ) ) {
		foreach ( $threefeature as $feature ) {
			++$i;
			$css['global'][ '.grid-item.item-' . $i . ' .grid-icon' ]['background-color'] = Digital_Sanitize::color( $feature['threefeature_icon_bg_color'] );
			$css['global'][ '.grid-item.item-' . $i . ' .grid-icon' ]['color']            = Digital_Sanitize::color( $feature['threefeature_icon_color'] );
		}
	}
	$css['global']['.threefeature-section'] = Digital_Sanitize::background( digital_get_settings( 'threefeature_background' ) );
	digital_merge_value( $css['global']['.threefeature-section'], Digital_Sanitize::padding( digital_get_settings( 'threefeature_padding' ) ) );
	digital_merge_value( $css['global']['.threefeature-section'], Digital_Sanitize::margin( digital_get_settings( 'threefeature_margin' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'threefeature_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'threefeature_text_font' ) ) );
	$threefeature_svg_position = digital_get_settings( 'threefeature_svg_position', array() );
	foreach ( $threefeature_svg_position as $key => $position ) {
		$css['global']['.section-svg.threefeature-svg'][ $key ] = $position;
	}

	// Testimonials Carousel
	$css['global']['.testimonials-carousel-section'] = Digital_Sanitize::background( digital_get_settings( 'testimonials_carousel_background' ) );
	digital_merge_value( $css['global']['.testimonials-carousel-section'], Digital_Sanitize::padding( digital_get_settings( 'testimonials_carousel_padding' ) ) );
	digital_merge_value( $css['global']['.testimonials-carousel-section'], Digital_Sanitize::margin( digital_get_settings( 'testimonials_carousel_margin' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'testimonials_carousel_tagline_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'testimonials_carousel_heading_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'testimonials_author_content_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'testimonials_author_name_font' ) ) );
	$carousel_svg_position = digital_get_settings( 'carousel_svg_position', array() );
	foreach ( $carousel_svg_position as $key => $position ) {
		$css['global']['.section-svg.carousel-svg'][ $key ] = $position;
	}

	// CTA
	$css['global']['.cta-section'] = Digital_Sanitize::background( digital_get_settings( 'cta_background' ) );
	digital_merge_value( $css['global']['.cta-section'], Digital_Sanitize::padding( digital_get_settings( 'cta_padding' ) ) );
	digital_merge_value( $css['global']['.cta-section'], Digital_Sanitize::margin( digital_get_settings( 'cta_margin' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'cta_heading_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'cta_text_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'cta_button_font' ) ) );
	$css['global']['.cta-button .button']['background-color']       = Digital_Sanitize::color( digital_get_settings( 'cta_button_bg' ) );
	$css['global']['.cta-button .button:hover']['color']            = Digital_Sanitize::color( digital_get_settings( 'cta_button_hover_color' ) );
	$css['global']['.cta-button .button:hover']['background-color'] = Digital_Sanitize::color( digital_get_settings( 'cta_button_hover_bg' ) );
	$cta_svg_position = digital_get_settings( 'cta_svg_position', array() );
	foreach ( $cta_svg_position as $key => $position ) {
		$css['global']['.section-svg.cta-svg'][ $key ] = $position;
	}

	// Blog Posts.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'blog_tagline_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'blog_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'blog_post_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'blog_post_content_font' ) ) );
	$css['global']['.blog-section'] = Digital_Sanitize::background( digital_get_settings( 'blog_background' ) );
	digital_merge_value( $css['global']['.blog-section'], Digital_Sanitize::padding( digital_get_settings( 'blog_padding' ) ) );
	digital_merge_value( $css['global']['.blog-section'], Digital_Sanitize::margin( digital_get_settings( 'blog_margin' ) ) );
	$blog_svg_position = digital_get_settings( 'blog_svg_position', array() );
	foreach ( $blog_svg_position as $key => $position ) {
		$css['global']['.section-svg.blog-svg'][ $key ] = $position;
	}

	// CTA 2
	$css['global']['.cta2-section'] = Digital_Sanitize::background( digital_get_settings( 'cta2_background' ) );
	digital_merge_value( $css['global']['.cta2-section'], Digital_Sanitize::padding( digital_get_settings( 'cta2_padding' ) ) );
	digital_merge_value( $css['global']['.cta2-section'], Digital_Sanitize::margin( digital_get_settings( 'cta2_margin' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'cta2_heading_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'cta2_text_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'cta2_button_font' ) ) );
	$css['global']['.cta2-button .button']['background-color']       = Digital_Sanitize::color( digital_get_settings( 'cta2_button_bg' ) );
	$css['global']['.cta2-button .button:hover']['color']            = Digital_Sanitize::color( digital_get_settings( 'cta2_button_hover_color' ) );
	$css['global']['.cta2-button .button:hover']['background-color'] = Digital_Sanitize::color( digital_get_settings( 'cta2_button_hover_bg' ) );
	$cta2_svg_position = digital_get_settings( 'cta2_svg_position', array() );
	foreach ( $cta2_svg_position as $key => $position ) {
		$css['global']['.section-svg.cta2-svg'][ $key ] = $position;
	}

	// Custom HTML5
	digital_merge_value( $css['global']['.html-section'], Digital_Sanitize::margin( digital_get_settings( 'html_margin' ) ) );
	digital_merge_value( $css['global']['.html-section'], Digital_Sanitize::padding( digital_get_settings( 'html_padding' ) ) );
}

/**
 * Pages Titles CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_pages_title( &$css ) {

	// Background.
	$css['global']['.pages-title-section'] = Digital_Sanitize::background( digital_get_settings( 'pages_title_background' ) );

	// Padding and Margin.
	digital_merge_value( $css['global']['.pages-title-section'], Digital_Sanitize::padding( digital_get_settings( 'pages_title_padding' ) ) );
	digital_merge_value( $css['global']['.pages-title-section'], Digital_Sanitize::margin( digital_get_settings( 'pages_title_margin' ) ) );

	// Typography.
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pages_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pages_subtitle_font' ) ) );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_post_layouts( &$css ) {

	// Post Layouts.
	$features = digital_get_settings( 'featured_categories' );
	foreach ( (array) $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.
		$post_title_align = digital_get_settings( 'post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Digital_Sanitize::background( digital_get_settings( 'featured_category_title_background_' . $unique_id ) );
		digital_merge_value( $css['global'][ $title_class ], Digital_Sanitize::margin( digital_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		digital_merge_value( $css['global'][ $title_class ], Digital_Sanitize::padding( digital_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Digital_Sanitize::border( digital_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align']              = 'right';
			$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
			$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
		endif;

		digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Digital_Sanitize::border( digital_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Meta info
		 */
		$css['global'][ $post_class . ' .latestPost .post-info .thecategory a' ]['color'] = Digital_Sanitize::color( digital_get_settings( 'meta_info_category_color_' . $unique_id ) );
		digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'meta_info_font_' . $unique_id ) ) );
		digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'readmore_font_' . $unique_id ) ) );
		digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'post_title_font_' . $unique_id ) ) );

		if ( 'layout-subscribe' !== $posts_layout ) {
			digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'post_excerpt_font_' . $unique_id ) ) );
		}

		// Border.
		$meta_info_border = Digital_Sanitize::border( digital_get_settings( 'meta_info_border_' . $unique_id ) );
		$css['global'][ $post_class . ' .latestPost .post-info' ][ $meta_info_border['direction'] ] = $meta_info_border['value'];

		// All Posts Margin and Padding.
		digital_merge_value( $css['global'][ $post_class ], Digital_Sanitize::margin( digital_get_settings( 'post_margin_' . $unique_id ) ) );
		digital_merge_value( $css['global'][ $post_class ], Digital_Sanitize::padding( digital_get_settings( 'post_padding_' . $unique_id ) ) );

		// Meta Info Margin Padding
		digital_merge_value( $css['global'][ $post_class . ' .latestPost .post-info' ], Digital_Sanitize::margin( digital_get_settings( 'meta_info_margin_' . $unique_id ) ) );
		digital_merge_value( $css['global'][ $post_class . ' .latestPost .post-info' ], Digital_Sanitize::padding( digital_get_settings( 'meta_info_padding_' . $unique_id ) ) );

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
		'#mobile-menu-wrapper ul li a:hover',
		'#load-posts a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'#load-posts a',
		'.single .pagination > .current .currenttext',
		'.pagination .page-numbers.dots',
		'.page-numbers.current',
	);
	if ( '2' !== digital_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ digital_implode( $pagination_class ) ]['background-color']        = Digital_Sanitize::color( digital_get_settings( 'mts_pagenavigation_bgcolor' ) );
		$css['global'][ digital_implode( $pagination_class_active ) ]['background-color'] = Digital_Sanitize::color( digital_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global'][ digital_implode( $pagination_class ) ]['color']                   = Digital_Sanitize::color( digital_get_settings( 'mts_pagenavigation_color' ) );
		$css['global'][ digital_implode( $pagination_class_active ) ]['color']            = Digital_Sanitize::color( digital_get_settings( 'mts_pagenavigation_hover_color' ) );
		$css['global'][ digital_implode( $pagination_class_active ) ]['border-color']     = Digital_Sanitize::color( digital_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		digital_merge_value( $css['global'][ digital_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Digital_Sanitize::margin( digital_get_settings( 'mts_pagenavigation_margin' ) ) );
		digital_merge_value( $css['global'][ digital_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Digital_Sanitize::padding( digital_get_settings( 'mts_pagenavigation_padding' ) ) );
		$css['global'][ digital_implode( $pagination_class ) ]['min-width']          = Digital_Sanitize::size( digital_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ digital_implode( $pagination_class_active ) ]['min-width']   = Digital_Sanitize::size( digital_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ digital_implode( $pagination_class ) ]['line-height']        = Digital_Sanitize::size( digital_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		$css['global'][ digital_implode( $pagination_class_active ) ]['line-height'] = Digital_Sanitize::size( digital_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		// Pagination border.
		$pagination_border = Digital_Sanitize::border( digital_get_settings( 'pagenavigation_border' ) );
		$css['global'][ digital_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];
		$pagination_hover_border = Digital_Sanitize::border( digital_get_settings( 'pagenavigation_hover_border' ) );
		$css['global'][ digital_implode( $pagination_class_active ) ][ $pagination_hover_border ['direction'] ] = $pagination_hover_border ['value'];
		$css['global'][ digital_implode( $pagination_class ) ]['border-radius']                                 = Digital_Sanitize::size( digital_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
		$css['global'][ digital_implode( $pagination_class_active ) ]['border-radius']                          = Digital_Sanitize::size( digital_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	} else {
		$css['global'][ digital_implode( $pagination_class ) ]['background-color']        = Digital_Sanitize::color( digital_get_settings( 'load_more_bgcolor' ) );
		$css['global'][ digital_implode( $pagination_class_active ) ]['background-color'] = Digital_Sanitize::color( digital_get_settings( 'load_more_hover_bgcolor' ) );
		$css['global'][ digital_implode( $pagination_class ) ]['color']                   = Digital_Sanitize::color( digital_get_settings( 'load_more_color' ) );
		$css['global'][ digital_implode( $pagination_class_active ) ]['color']            = Digital_Sanitize::color( digital_get_settings( 'load_more_hover_color' ) );
		digital_merge_value( $css['global'][ digital_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Digital_Sanitize::padding( digital_get_settings( 'load_more_padding' ) ) );
		digital_merge_value( $css['global'][ digital_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Digital_Sanitize::margin( digital_get_settings( 'load_more_margin' ) ) );
		$css['global'][ digital_implode( $pagination_class_active ) ]['border-color'] = Digital_Sanitize::color( digital_get_settings( 'load_more_hover_bgcolor' ) );
		// Load More border.
		$load_more_border = Digital_Sanitize::border( digital_get_settings( 'load_more_border' ) );
		$css['global'][ digital_implode( $pagination_class ) ][ $load_more_border ['direction'] ] = $load_more_border ['value'];
		$css['global'][ digital_implode( $pagination_class ) ]['border-radius']                   = Digital_Sanitize::size( digital_get_settings( 'load_more_border_radius' ) . 'px' );
		$css['global'][ digital_implode( $pagination_class_active ) ]['border-radius']            = Digital_Sanitize::size( digital_get_settings( 'load_more_border_radius' ) . 'px' );
	}

	// Load more Alignment.
	$load_more_align = digital_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_single( &$css ) {

	// Single, Page and 404 Page Background.
	$page_classes = array(
		'.page .article',
		'.error404 .article',
	);

	$css['global'][ digital_implode( $page_classes ) ] = Digital_Sanitize::background( digital_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	digital_merge_value( $css['global']['.article'], Digital_Sanitize::margin( digital_get_settings( 'mts_single_styling_margin' ) ) );
	digital_merge_value( $css['global'][ digital_implode( $page_classes ) ], Digital_Sanitize::padding( digital_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Digital_Sanitize::border( digital_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	// Single Post Meta Info
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'mts_single_meta_info_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'mts_single_category_font' ) ) );

	// Related Posts.
	$css['global']['.related-posts'] = Digital_Sanitize::background( digital_get_settings( 'related_posts_background' ) );

	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'related_posts_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'related_meta_info_font' ) ) );
	$css['global']['.related-posts .latestPost .post-info .thecategory a']['color'] = Digital_Sanitize::color( digital_get_settings( 'related_meta_info_category_color' ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'related_readmore_font' ) ) );

	digital_merge_value( $css['global']['.related-posts'], Digital_Sanitize::margin( digital_get_settings( 'related_posts_margin' ) ) );
	digital_merge_value( $css['global']['.related-posts'], Digital_Sanitize::padding( digital_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Digital_Sanitize::border( digital_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Digital_Sanitize::background( digital_get_settings( 'related_article_background' ) );
	digital_merge_value( $css['global']['.related-posts article'], Digital_Sanitize::padding( digital_get_settings( 'related_article_padding' ) ) );
	digital_merge_value( $css['global']['.related-posts article header'], Digital_Sanitize::padding( digital_get_settings( 'related_article_text_padding' ) ) );

	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Digital_Sanitize::background( digital_get_settings( 'single_subscribe_background' ) );
	digital_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Digital_Sanitize::margin( digital_get_settings( 'single_subscribe_margin' ) ) );
	digital_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Digital_Sanitize::padding( digital_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Digital_Sanitize::size( digital_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ digital_implode( $subscribe_input_class ) ]['background-color'] = Digital_Sanitize::color( digital_get_settings( 'single_subscribe_input_background' ) );

	$css['global'][ digital_implode( $subscribe_input_class ) ]['height'] = Digital_Sanitize::size( digital_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Digital_Sanitize::size( digital_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ digital_implode( $subscribe_input_class ) ]['border-radius'] = Digital_Sanitize::size( digital_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Digital_Sanitize::border( digital_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ digital_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Digital_Sanitize::color( digital_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Digital_Sanitize::size( digital_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Digital_Sanitize::border( digital_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	digital_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Digital_Sanitize::padding( digital_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Digital_Sanitize::background( digital_get_settings( 'authorbox_background' ) );

	digital_merge_value( $css['global']['.postauthor'], Digital_Sanitize::margin( digital_get_settings( 'authorbox_margin' ) ) );

	digital_merge_value( $css['global']['.postauthor'], Digital_Sanitize::padding( digital_get_settings( 'authorbox_padding' ) ) );

	$css['global']['.postauthor']['border-radius'] = Digital_Sanitize::size( digital_get_settings( 'authorbox_border_radius' ) . 'px' );

	$authorbox_border = Digital_Sanitize::border( digital_get_settings( 'authorbox_border' ) );
	$css['global']['.postauthor'][ $authorbox_border ['direction'] ] = $authorbox_border ['value'];

	// Author image.
	digital_merge_value( $css['global']['.postauthor img'], Digital_Sanitize::margin( digital_get_settings( 'single_author_image_margin' ) ) );

	$css['global']['.postauthor img']['border-radius'] = Digital_Sanitize::size( digital_get_settings( 'single_author_image_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = digital_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ digital_implode( $titles_class ) ] = Digital_Sanitize::background( digital_get_settings( 'single_title_background' ) );
	digital_merge_value( $css['global'][ digital_implode( $titles_class ) ], Digital_Sanitize::padding( digital_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Digital_Sanitize::border( digital_get_settings( 'single_title_border' ) );
	$css['global'][ digital_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ digital_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ digital_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ digital_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ digital_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ digital_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_copyrights( &$css ) {

	$css['global']['.copyrights'] = Digital_Sanitize::background( digital_get_settings( 'mts_copyrights_background' ) );
	digital_merge_value( $css['global']['.copyrights'], Digital_Sanitize::margin( digital_get_settings( 'mts_copyrights_margin' ) ) );
	digital_merge_value( $css['global']['.copyrights'], Digital_Sanitize::padding( digital_get_settings( 'mts_copyrights_padding' ) ) );
	$copyrights_border = Digital_Sanitize::border( digital_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'copyrights_font' ) ) );
	// Footer Social icons.
	if ( ! empty( digital_get_settings( 'mts_footer_social_share' ) ) && ! empty( digital_get_settings( 'footer_social_icons' ) ) && is_array( digital_get_settings( 'footer_social_icons' ) ) ) :
		$footer_icons = digital_get_settings( 'footer_social_icons' );
		foreach ( $footer_icons as $footer_icon ) :
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ]['background-color']            = Digital_Sanitize::color( $footer_icon['footer_icon_bgcolor'] );
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] . ':hover' ]['background-color'] = Digital_Sanitize::color( $footer_icon['footer_icon_hover_bgcolor'] );
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ]['color']                       = Digital_Sanitize::color( $footer_icon['footer_icon_color'] );
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] . ':hover' ]['color']            = Digital_Sanitize::color( $footer_icon['footer_icon_hover_color'] );
			digital_merge_value( $css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ], Digital_Sanitize::margin( $footer_icon['footer_icon_margin'] ) );
			digital_merge_value( $css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ], Digital_Sanitize::padding( $footer_icon['footer_icon_padding'] ) );
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['footer_icon'] ]['border-radius'] = Digital_Sanitize::size( $footer_icon['footer_icon_border_radius'] . 'px' );
		endforeach;
	endif;

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_footer( &$css ) {
	// Footer.
	if ( digital_get_settings( 'mts_top_footer' ) ) {
		digital_merge_value( $css['global']['#site-footer'], Digital_Sanitize::margin( digital_get_settings( 'mts_top_footer_margin' ) ) );
		digital_merge_value( $css['global']['#site-footer'], Digital_Sanitize::padding( digital_get_settings( 'mts_top_footer_padding' ) ) );
	}
}

/**
 * Pricing
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_pricing( &$css ) {
	/**
	 * Pricing Table
	 */
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_subheading_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_text_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_amount_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'recommended_button_font' ) ) );
	$css['global']['.pricing-button .button']['background']       = Digital_Sanitize::color( digital_get_settings( 'pricing_button_bg' ) );
	$css['global']['.pricing-button .button']['color']            = Digital_Sanitize::color( digital_get_settings( 'pricing_button_color' ) );
	$css['global']['.pricing-button .button:hover']['background'] = Digital_Sanitize::color( digital_get_settings( 'pricing_button_hover_bg' ) );
	$css['global']['.pricing-button .button:hover']['color']      = Digital_Sanitize::color( digital_get_settings( 'pricing_button_hover_color' ) );

	$pricing = digital_get_settings( 'pricing_table' );
	$i       = 0;
	if ( ! empty( $pricing ) && is_array( $pricing ) ) {
		foreach ( $pricing as $price ) {
			++$i;
			$css['global'][ '.pricing-item.item-' . $i . ' .pricing-item-upper-area' ]['background-color'] = Digital_Sanitize::color( $price['pricing_table_bg'] );
			//text color
			$css['global'][ '.pricing-item.item-' . $i . ' h3' ]['color']              = Digital_Sanitize::color( $price['pricing_table_title_color'] );
			$css['global'][ '.pricing-item.item-' . $i . ' .pricing-list p' ]['color'] = Digital_Sanitize::color( $price['pricing_table_text_color'] );
			$css['global'][ '.pricing-item.item-' . $i . ' .pricing-amount' ]['color'] = Digital_Sanitize::color( $price['pricing_amount_color'] );
			//Recommended Button
			//$css['global'][ '.pricing-item.item-' . $i . ' .recommended-button' ]['display'] = 'block';
		}
	}
	$css['global']['.recommended-button .button']['background'] = Digital_Sanitize::color( digital_get_settings( 'recommended_button_bg' ) );
	digital_merge_value( $css['global']['.pricing-section'], Digital_Sanitize::margin( digital_get_settings( 'pricing_table_margin' ) ) );
	digital_merge_value( $css['global']['.pricing-section'], Digital_Sanitize::padding( digital_get_settings( 'pricing_table_padding' ) ) );

	// FAQs
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_faqs_heading_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_faqs_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_faqs_text_font' ) ) );
	digital_merge_value( $css['global']['.faq-section'], Digital_Sanitize::margin( digital_get_settings( 'pricing_faqs_margin' ) ) );
	digital_merge_value( $css['global']['.faq-section'], Digital_Sanitize::padding( digital_get_settings( 'pricing_faqs_padding' ) ) );

	//Brands
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_brands_heading_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'pricing_brands_subheading_font' ) ) );
	digital_merge_value( $css['global']['.pricing-brands-section'], Digital_Sanitize::margin( digital_get_settings( 'pricing_brands_margin' ) ) );
	digital_merge_value( $css['global']['.pricing-brands-section'], Digital_Sanitize::padding( digital_get_settings( 'pricing_brands_padding' ) ) );

	//Ads
	$css['global']['.pricing-ad-section'] = Digital_Sanitize::background( digital_get_settings( 'pricing_ad_background' ) );
	digital_merge_value( $css['global']['.pricing-ad-section'], Digital_Sanitize::margin( digital_get_settings( 'pricing_ad_margin' ) ) );
	digital_merge_value( $css['global']['.pricing-ad-section'], Digital_Sanitize::padding( digital_get_settings( 'pricing_ad_padding' ) ) );
}

/**
 * Archives
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_archives( &$css ) {
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'archive_post_title_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'archive_post_excerpt_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'archive_meta_info_font' ) ) );
	digital_map_css_selectors( $css['global'], Digital_Sanitize::typography( digital_get_settings( 'archive_readmore_font' ) ) );
	$elements = array(
		'.archive .latestPost .thecategory a',
		'.search .latestPost .thecategory a',
	);
	$css['global'][ digital_implode( $elements ) ]['color'] = Digital_Sanitize::color( digital_get_settings( 'archive_category_color' ) );
}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function digital_misc_css( &$css ) {

	// Show Logo.
	$show_logo = digital_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	// Border.
	$top_button_border = Digital_Sanitize::border( digital_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Digital_Sanitize::size( digital_get_settings( 'top_button_font_size' ) . 'px' );
	digital_merge_value( $css['global']['#move-to-top'], Digital_Sanitize::padding( digital_get_settings( 'top_button_padding' ) ) );
	$top_button_position = digital_get_settings( 'top_button_position', array() );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Digital_Sanitize::size( digital_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']            = Digital_Sanitize::color( digital_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color']      = Digital_Sanitize::color( digital_get_settings( 'top_button_color_hover' ) );
	$css['global']['#move-to-top']['background']       = Digital_Sanitize::color( digital_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover']['background'] = Digital_Sanitize::color( digital_get_settings( 'top_button_background_hover' ) );

	// widgets margin
	$widgets_margin = Digital_Sanitize::padding( digital_get_settings( 'mts_sidebar_styling_padding', array() ) );
	$elements       = array(
		'.sidebar .widget.instagram-widget-wrapper .instagram-posts',
		'#sidebar #searchform',
		'.sidebar .aboutme-image',
		'.sidebar .widget .vertical-small .post-img',
		'.sidebar .widget .wpt_thumb_large',
		'.sidebar .widget .wp_review_tab_thumb_large',
		'.sidebar .widget .wpt-tabs',
		'.sidebar .widget .wp-review-tabs',
	);
	$css['global'][ digital_implode( $elements ) ]['margin-left']  = '-' . ( isset( $widgets_margin['padding-left'] ) ? $widgets_margin['padding-left'] : '0' );
	$css['global'][ digital_implode( $elements ) ]['margin-right'] = '-' . ( isset( $widgets_margin['padding-right'] ) ? $widgets_margin['padding-right'] : '0' );
}
